summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabeldict/searchengine.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabeldict/searchengine.h')
-rw-r--r--kbabel/kbabeldict/searchengine.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kbabel/kbabeldict/searchengine.h b/kbabel/kbabeldict/searchengine.h
index f14baa1e..c5b28ad5 100644
--- a/kbabel/kbabeldict/searchengine.h
+++ b/kbabel/kbabeldict/searchengine.h
@@ -247,7 +247,7 @@ class KDE_EXPORT PrefWidget : public TQWidget
TQ_OBJECT
public:
- PrefWidget(TQWidget *tqparent, const char* name=0);
+ PrefWidget(TQWidget *parent, const char* name=0);
virtual ~PrefWidget();
public slots:
@@ -272,7 +272,7 @@ class KDE_EXPORT SearchEngine : public TQObject
TQ_OBJECT
public:
- SearchEngine(TQObject *tqparent=0, const char *name=0);
+ SearchEngine(TQObject *parent=0, const char *name=0);
virtual ~SearchEngine();
@@ -354,9 +354,9 @@ public:
* search engine. The returned widget should not be bigger than
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
* @param tqparent the tqparent of the returned widget
*/
- virtual PrefWidget* preferencesWidget(TQWidget *tqparent)=0;
+ virtual PrefWidget* preferencesWidget(TQWidget *parent)=0;
/** @returns information about this SearchEngine */
virtual const KAboutData *about() const= 0;
@@ -354,9 +354,9 @@ public:
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
- * @param tqparent the tqparent of the returned widget
+ * @param parent the parent of the returned widget
*/